# Plotting columns of data from a file

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
from matplotlib.ticker import FixedLocator, NullFormatter

df = pd.read_csv('diff_results.dat', sep='\s+', names=['h', 'f', 'c'])

plt.figure(figsize=(8, 6))
plt.loglog(df.h, df.f, 'ko-', label='Forward Difference')
plt.loglog(df.h, df.c, 'ro-', label='Centered Difference')




#fit forward first 5 points of forward difference
#
# Fitting code will go here.



# Generate tick mark locations
def generate_minor_ticks(start, stop, num_minor):
    return np.linspace(start, stop, num_minor + 2)[1:-1]

majorxticks = np.logspace(-15,0,16)
majoryticks = np.logspace(-14,0,15)

# Set major and minor tick locators for x-axis
plt.gca().xaxis.set_major_locator(FixedLocator(majorxticks))
# Generate minor ticks for x-axis
minor_xticks = []
for i in range(len(majorxticks) - 1):
    minor_xticks.extend(generate_minor_ticks(majorxticks[i], majorxticks[i + 1], 9))

plt.gca().xaxis.set_minor_locator(FixedLocator(minor_xticks))
plt.gca().xaxis.set_minor_formatter(NullFormatter())  # Remove minor tick labels

# Set major and minor tick locators for y-axis
plt.gca().yaxis.set_major_locator(FixedLocator(majoryticks))  # Major ticks every factor of ten
# Generate minor ticks for y-axis
minor_yticks = []
for i in range(len(majoryticks) - 1):
    minor_yticks.extend(generate_minor_ticks(majoryticks[i], majoryticks[i + 1], 9))

plt.gca().yaxis.set_minor_locator(FixedLocator(minor_yticks))
plt.gca().yaxis.set_minor_formatter(NullFormatter())  # Remove minor tick labels

n = 2  # Keeps every 2nd label
[l.set_visible(False) for (i,l) in enumerate(plt.gca().xaxis.get_ticklabels()) if i % n == 0]








# label axes
plt.xlabel('Step size')
plt.ylabel('Absolute error')

# axes scales
#plt.xlim(0,10)
#plt.ylim(-5,5)
plt.legend()

# save the plot as an image
plt.savefig('diff_results_py.pdf')
#plt.savefig('diff_results_py.eps',format='eps')

plt.show()
